@@ -25,23 +25,12 @@
 #include "state_tracker/shader_module.h"
 #include "state_tracker/state_tracker.h"
 #include "state_tracker/cmd_buffer_state.h"
+#include "containers/container_utils.h"
 #include <string>
 #include <deque>
 #include <chrono>
 #include <set>
 
-enum class DeprecationReason {
-    Empty = 0,
-    Promoted,
-    Obsoleted,
-    Deprecated,
-};
-
-struct DeprecationData {
-    DeprecationReason reason;
-    vvl::Requirement target;
-};
-
 struct ShaderStageState;
 struct LastBound;
 
@@ -50,7 +39,6 @@ struct EntryPoint;
 struct Module;
 }  // namespace spirv
 
-DeprecationData GetDeprecatedData(vvl::Extension extension);
 std::string GetSpecialUse(vvl::Extension extension);
 
 namespace bp_state {
@@ -93,7 +81,6 @@ class Instance : public vvl::InstanceProxy {
     bool PreCallValidateCreateDevice(VkPhysicalDevice physicalDevice, const VkDeviceCreateInfo* pCreateInfo,
                                      const VkAllocationCallbacks* pAllocator, VkDevice* pDevice,
                                      const ErrorObject& error_obj) const override;
-    bool ValidateDeprecatedExtensions(const Location& loc, vvl::Extension extension, APIVersion version) const;
 
     bool ValidateSpecialUseExtensions(const Location& loc, vvl::Extension extension) const;
 
